Flaticon WebFont

Instructions

- 1Copy the "Fonts" files and CSS files to your website CSS folder.
- 2Add the CSS link to your website source code on header. `<head>
  ...
  <link rel="stylesheet" type="text/css" href="your_website_domain/css_root/flaticon.css">
  ...
  </head>`

- 3Use the icon class on `"display: inline"` elements:
  Use example: `<i class="flaticon-airplane49"></i>` or `<span class="flaticon-airplane49"></span>`

.flaticon-delivery-truck
Author: Smashicons
.flaticon-shopping-bag
Author: Smashicons
.flaticon-box-3
Author: Smashicons
.flaticon-box-2
Author: Smashicons
.flaticon-box-1
Author: Smashicons
.flaticon-laptop
Author: Smashicons
.flaticon-coffee-cup
Author: Smashicons
.flaticon-user-6
Author: Smashicons
.flaticon-user-5
Author: Smashicons
.flaticon-remove-user-1
Author: Smashicons
.flaticon-customer-support
Author: Smashicons
.flaticon-user-4
Author: Smashicons
.flaticon-user-3
Author: Smashicons
.flaticon-user-2
Author: Smashicons
.flaticon-remove-user
Author: Smashicons
.flaticon-add-user
Author: Smashicons
.flaticon-tea-cup
Author: Smashicons
.flaticon-pen
Author: Smashicons
.flaticon-desk
Author: Smashicons
.flaticon-ruler
Author: Smashicons
.flaticon-pencil
Author: Smashicons
.flaticon-analytics
Author: Smashicons
.flaticon-google-plus
Author: Smashicons
.flaticon-dribbble
Author: Smashicons
.flaticon-whatsapp
Author: Smashicons
.flaticon-twitter
Author: Smashicons
.flaticon-behance
Author: Smashicons
.flaticon-instagram
Author: Smashicons
.flaticon-android
Author: Smashicons
.flaticon-apple
Author: Smashicons
.flaticon-windows
Author: Smashicons
.flaticon-pinterest
Author: Smashicons
.flaticon-youtube
Author: Smashicons
.flaticon-paypal
Author: Smashicons
.flaticon-linkedin
Author: Smashicons
.flaticon-facebook
Author: Smashicons
.flaticon-lock-1
Author: Smashicons
.flaticon-lock
Author: Smashicons
.flaticon-profile-1
Author: Smashicons
.flaticon-profile
Author: Smashicons
.flaticon-user-1
Author: Smashicons
.flaticon-user
Author: Smashicons
.flaticon-users
Author: Smashicons
.flaticon-message
Author: Smashicons
.flaticon-placeholder-1
Author: Smashicons
.flaticon-location
Author: Smashicons
.flaticon-arrows-2
Author: Smashicons
.flaticon-technology-2
Author: Smashicons
.flaticon-multimedia-2
Author: Smashicons
.flaticon-multimedia-1
Author: Smashicons
.flaticon-close
Author: Smashicons
.flaticon-home
Author: Smashicons
.flaticon-circle
Author: Smashicons
.flaticon-arrow
Author: Smashicons
.flaticon-mark-1
Author: Smashicons
.flaticon-mark
Author: Smashicons
.flaticon-shapes-1
Author: Smashicons
.flaticon-search-2
Author: Smashicons
.flaticon-interface-7
Author: Smashicons
.flaticon-suitcase
Author: Smashicons
.flaticon-chain-1
Author: Smashicons
.flaticon-chain
Author: Smashicons
.flaticon-agenda-1
Author: Smashicons
.flaticon-interface-6
Author: Smashicons
.flaticon-calendar
Author: Smashicons
.flaticon-list
Author: Smashicons
.flaticon-file-1
Author: Smashicons
.flaticon-file
Author: Smashicons
.flaticon-interface-5
Author: Smashicons
.flaticon-folder
Author: Smashicons
.flaticon-stopwatch
Author: Smashicons
.flaticon-time
Author: Smashicons
.flaticon-clock-1
Author: Smashicons
.flaticon-search-1
Author: Smashicons
.flaticon-music-1
Author: Smashicons
.flaticon-music
Author: Smashicons
.flaticon-present
Author: Smashicons
.flaticon-layers-1
Author: Smashicons
.flaticon-settings
Author: Smashicons
.flaticon-attachment
Author: Smashicons
.flaticon-gestures
Author: Smashicons
.flaticon-tool
Author: Smashicons
.flaticon-interface-4
Author: Smashicons
.flaticon-interface-3
Author: Smashicons
.flaticon-agenda
Author: Smashicons
.flaticon-shapes
Author: Smashicons
.flaticon-symbol-1
Author: Smashicons
.flaticon-symbol
Author: Smashicons
.flaticon-interface-2
Author: Smashicons
.flaticon-layers
Author: Smashicons
.flaticon-clock
Author: Smashicons
.flaticon-web-1
Author: Smashicons
.flaticon-internet
Author: Smashicons
.flaticon-placeholder
Author: Smashicons
.flaticon-signs-3
Author: Smashicons
.flaticon-star-1
Author: Smashicons
.flaticon-web
Author: Smashicons
.flaticon-star
Author: Smashicons
.flaticon-like-1
Author: Smashicons
.flaticon-like
Author: Smashicons
.flaticon-cloud
Author: Smashicons
.flaticon-database
Author: Smashicons
.flaticon-technology-1
Author: Smashicons
.flaticon-idea
Author: Smashicons
.flaticon-search
Author: Smashicons
.flaticon-wifi
Author: Smashicons
.flaticon-hands-1
Author: Smashicons
.flaticon-hands
Author: Smashicons
.flaticon-bars-2
Author: Smashicons
.flaticon-arrows-1
Author: Smashicons
.flaticon-interface-1
Author: Smashicons
.flaticon-network
Author: Smashicons
.flaticon-share-1
Author: Smashicons
.flaticon-share
Author: Smashicons
.flaticon-bars-1
Author: Smashicons
.flaticon-cross-1
Author: Smashicons
.flaticon-line-1
Author: Smashicons
.flaticon-signs-2
Author: Smashicons
.flaticon-check
Author: Smashicons
.flaticon-technology
Author: Smashicons
.flaticon-bars
Author: Smashicons
.flaticon-cross
Author: Smashicons
.flaticon-add
Author: Smashicons
.flaticon-power
Author: Smashicons
.flaticon-signs-1
Author: Smashicons
.flaticon-round
Author: Smashicons
.flaticon-exclamation
Author: Smashicons
.flaticon-success
Author: Smashicons
.flaticon-error
Author: Smashicons
.flaticon-line
Author: Smashicons
.flaticon-plus
Author: Smashicons
.flaticon-interface
Author: Smashicons
.flaticon-signs
Author: Smashicons
.flaticon-play-button-1
Author: Smashicons
.flaticon-play-button
Author: Smashicons
.flaticon-music-player
Author: Smashicons
.flaticon-medical
Author: Smashicons
.flaticon-photo-camera
Author: Smashicons
.flaticon-picture
Author: Smashicons
.flaticon-multimedia
Author: Smashicons
.flaticon-game-controller
Author: Smashicons
.flaticon-imac
Author: Smashicons
.flaticon-paint-palette
Author: Smashicons
.flaticon-envelope-3
Author: Smashicons
.flaticon-envelope-2
Author: Smashicons
.flaticon-envelope-1
Author: Smashicons
.flaticon-envelope
Author: Smashicons
.flaticon-mailbox
Author: Smashicons
.flaticon-inbox
Author: Smashicons
.flaticon-chat-8
Author: Smashicons
.flaticon-chat-7
Author: Smashicons
.flaticon-chat-6
Author: Smashicons
.flaticon-chat-5
Author: Smashicons
.flaticon-chat-4
Author: Smashicons
.flaticon-chat-3
Author: Smashicons
.flaticon-chat-2
Author: Smashicons
.flaticon-chat-1
Author: Smashicons
.flaticon-chat
Author: Smashicons
.flaticon-archive
Author: Smashicons
.flaticon-diagram
Author: Smashicons
.flaticon-graph-2
Author: Smashicons
.flaticon-graph-1
Author: Smashicons
.flaticon-graph
Author: Smashicons
.flaticon-chart-pie
Author: Smashicons
.flaticon-presentation
Author: Smashicons
.flaticon-store
Author: Smashicons
.flaticon-coins
Author: Smashicons
.flaticon-credit-card-1
Author: Smashicons
.flaticon-credit-card
Author: Smashicons
.flaticon-cart-1
Author: Smashicons
.flaticon-cart
Author: Smashicons
.flaticon-price-tag
Author: Smashicons
.flaticon-box
Author: Smashicons
.flaticon-right-arrow-4
Author: Smashicons
.flaticon-left-arrow-4
Author: Smashicons
.flaticon-up-arrow-3
Author: Smashicons
.flaticon-download-1
Author: Smashicons
.flaticon-down-arrow-3
Author: Smashicons
.flaticon-up-arrow-2
Author: Smashicons
.flaticon-left-arrow-3
Author: Smashicons
.flaticon-right-arrow-3
Author: Smashicons
.flaticon-down-arrow-2
Author: Smashicons
.flaticon-arrows
Author: Smashicons
.flaticon-left-arrow-2
Author: Smashicons
.flaticon-right-arrow-2
Author: Smashicons
.flaticon-upward
Author: Smashicons
.flaticon-download
Author: Smashicons
.flaticon-back
Author: Smashicons
.flaticon-next
Author: Smashicons
.flaticon-up-arrow-1
Author: Smashicons
.flaticon-down-arrow-1
Author: Smashicons
.flaticon-left-arrow-1
Author: Smashicons
.flaticon-right-arrow-1
Author: Smashicons
.flaticon-up-arrow
Author: Smashicons
.flaticon-down-arrow
Author: Smashicons
.flaticon-left-arrow
Author: Smashicons
.flaticon-right-arrow
Author: Smashicons
.flaticon-expand
Author: Smashicons
.flaticon-repeat
Author: Smashicons
License and attribution:
Font generated by flaticon.com.

Under CC: Smashicons

Copy the Attribution License:
Font generated by <a href="https://www.flaticon.com">flaticon.com</a>. <p>Under <a href="https://creativecommons.org/licenses/by/3.0/">CC</a>: <a data-file="001-delivery-truck" href="https://www.flaticon.com/authors/smashicons">Smashicons</a></p>
Examples:

<i class="flaticon-delivery-truck"></i>

<i class="flaticon-shopping-bag"></i>

<i class="flaticon-box-3"></i>

<i class="flaticon-box-2"></i>